"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const got_1 = __importDefault(require("got"));
const gunzip_maybe_1 = __importDefault(require("gunzip-maybe"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const tar_stream_1 = __importDefault(require("tar-stream"));
const unpacker_1 = require("./download-helpers/unpacker");
async function downloadCode(organization, repository, sha, debug) {
    console.log('DOWNLOADING CODE:', sha);
    const url = `https://api.github.com/repos/${organization}/${repository}/tarball/${sha}`;
    const responseStream = await got_1.default.stream(url, {
        headers: {
            Accept: 'application/vnd.github.v3.raw',
            Authorization: `token ${process.env.GITHUB_ACCESS_TOKEN}`,
            'User-Agent': 'Probot-Kit',
            followRedirect: true
        }
    });
    const tarExtractor = tar_stream_1.default.extract();
    const unpacker = new unpacker_1.TarUnpacker(debug);
    tarExtractor.on('entry', unpacker.unpackEntry.bind(unpacker));
    return new Promise((resolve, reject) => {
        tarExtractor.on('error', reject);
        tarExtractor.on('finish', () => {
            resolve(path_1.default.join(os_1.default.tmpdir(), `${organization}-${repository}-${sha}`));
        });
        responseStream.pipe(gunzip_maybe_1.default()).pipe(tarExtractor);
    });
}
exports.downloadCode = downloadCode;
