"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
class TarUnpacker {
    constructor(debug) {
        this.debug = debug;
    }
    unpackEntry(header, bodyStream, rootDir, next) {
        const entryPath = path_1.default.join(rootDir, header.name);
        if (header.type === 'directory') {
            this.extractDirectoryEntry(entryPath, next);
        }
        else if (header.type === 'file') {
            this.extractFileEntry(entryPath, bodyStream, next);
        }
        else if (header.type === 'symlink') {
            this.extractSymlinkEntry(next);
        }
        else {
            throw new Error(`UNKNOWN HEADER TYPE: ${header.type}`);
        }
    }
    extractDirectoryEntry(dirPath, next) {
        if (this.debug) {
            console.log('creating directory:', dirPath);
        }
        if (!fs_1.default.existsSync(dirPath)) {
            fs_1.default.mkdirSync(dirPath);
        }
        next();
    }
    extractFileEntry(filePath, bodyStream, next) {
        if (this.debug) {
            console.log('creating file:', filePath);
        }
        const fileStream = fs_1.default.createWriteStream(filePath);
        bodyStream.on('end', next);
        bodyStream.pipe(fileStream);
    }
    extractSymlinkEntry(next) {
        next();
    }
}
exports.TarUnpacker = TarUnpacker;
